@@ -20,9 +20,11 @@
 
 #include "eigenvectorsassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+#include <QPushButton>
+#include <QDialog>
 #include <KActionCollection>
+#include <KConfigGroup>
 #include "cantor_macros.h"
 #include "backend.h"
 #include "extension.h"
@@ -41,19 +43,25 @@ EigenVectorsAssistant::~EigenVectorsAssistant()
 void EigenVectorsAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_eigenvectors_assistant.rc"));
-    KAction* eigenvectors=new KAction(i18n("Compute Eigenvectors"), actionCollection());
-    //eigenvectors->setIcon(KIcon(icon()));
+    QAction* eigenvectors=new QAction(i18n("Compute Eigenvectors"), actionCollection());
     actionCollection()->addAction(QLatin1String("eigenvectors_assistant"), eigenvectors);
-    connect(eigenvectors, &KAction::triggered, this, &EigenVectorsAssistant::requested);
+    connect(eigenvectors, &QAction::triggered, this, &EigenVectorsAssistant::requested);
 }
 
 QStringList EigenVectorsAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget* widget=new QWidget(dlg);
     Ui::EigenVectorsAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
 
     Cantor::HistoryExtension* hist=
         dynamic_cast<Cantor::HistoryExtension*>(backend()->extension(QLatin1String("HistoryExtension")));
