@@ -20,9 +20,12 @@
 
 #include "invertmatrixassistant.h"
 
-#include <KDialog>
-#include <KAction>
+#include <QAction>
+
+#include <QDialog>
+#include <QPushButton>
 #include <KActionCollection>
+#include <KConfigGroup>
 #include "cantor_macros.h"
 #include "backend.h"
 #include "extension.h"
@@ -41,19 +44,25 @@ InvertMatrixAssistant::~InvertMatrixAssistant()
 void InvertMatrixAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_invert_matrix_assistant.rc"));
-    KAction* invertmatrix=new KAction(i18n("Invert Matrix"), actionCollection());
-    //invertmatrix->setIcon(KIcon(icon()));
+    QAction* invertmatrix=new QAction(i18n("Invert Matrix"), actionCollection());
     actionCollection()->addAction(QLatin1String("invertmatrix_assistant"), invertmatrix);
-    connect(invertmatrix, &KAction::triggered, this, &InvertMatrixAssistant::requested);
+    connect(invertmatrix, &QAction::triggered, this, &InvertMatrixAssistant::requested);
 }
 
 QStringList InvertMatrixAssistant::run(QWidget* parent)
 {
-    QPointer<KDialog> dlg=new KDialog(parent);
+    QPointer<QDialog> dlg=new QDialog(parent);
     QWidget* widget=new QWidget(dlg);
     Ui::InvertMatrixAssistantBase base;
     base.setupUi(widget);
-    dlg->setMainWidget(widget);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(widget);
+
+    base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
+    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
 
     Cantor::HistoryExtension* hist=
         dynamic_cast<Cantor::HistoryExtension*>(backend()->extension(QLatin1String("HistoryExtension")));
